This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Represents text modality. If specified, it will sanitize text fields, and
text extracted from rich text files (like PDFs, DOCs) and plain text files
(like TXT).
Represents image modality. If specified, it will sanitize image files. The
visual content and the text content in the image will be sanitized
depending on the filter configuration.